@@ -70,6 +70,10 @@ enum Commands {
     /// Commit staged release requests to the `rc` branch
     Confirm(ConfirmCommand),
 
+    #[structopt(name = "diff")]
+    /// Show "diff" output since the latest release
+    Diff(DiffCommand),
+
     #[structopt(name = "github")]
     /// GitHub release utilities
     Github(github::GithubCommand),
@@ -125,6 +129,7 @@ impl Command for Commands {
             Commands::Cargo(o) => o.execute(),
             Commands::CiUtil(o) => o.execute(),
             Commands::Confirm(o) => o.execute(),
+            Commands::Diff(o) => o.execute(),
             Commands::Github(o) => o.execute(),
             Commands::GitUtil(o) => o.execute(),
             Commands::Help(o) => o.execute(),
@@ -329,7 +334,7 @@ impl Command for ConfirmCommand {
 
                 let (old_version_text, new_version) = {
                     let proj = graph.lookup_mut(ident);
-                    let last_rel_info = history.release_info(&repo)?;
+                    let last_rel_info = history.release_info(repo)?;
                     let scheme = proj.version.parse_bump_scheme(&info.bump_spec)?;
 
                     if let Some(last_release) = last_rel_info.lookup_project(proj) {
@@ -398,6 +403,60 @@ impl Command for ConfirmCommand {
     }
 }
 
+// diff
+
+#[derive(Debug, PartialEq, StructOpt)]
+struct DiffCommand {
+    #[structopt(help = "Name of the project to query")]
+    proj_names: Vec<String>,
+}
+
+impl Command for DiffCommand {
+    fn execute(self) -> Result<i32> {
+        // See also "log" -- these follow similar patterns
+        let sess = app::AppSession::initialize_default()?;
+
+        let mut q = graph::GraphQueryBuilder::default();
+        q.names(self.proj_names);
+        let idents = sess.graph().query(q)?;
+        if idents.len() != 1 {
+            bail!("must specify exactly one project to diff");
+        }
+        let ident = idents[0];
+
+        let dir = sess
+            .repo
+            .resolve_workdir(sess.graph().lookup(ident).prefix());
+
+        let histories = atry!(
+            sess.analyze_histories();
+            ["failed to analyze the repository history"]
+        );
+
+        let history = histories.lookup(ident);
+
+        let commit = match history.main_branch_commit(&sess.repo)? {
+            Some(c) => c,
+            None => {
+                println!(
+                    "no known last release commit to diff against for `{}`",
+                    sess.graph().lookup(ident).user_facing_name
+                );
+                return Ok(0);
+            }
+        };
+
+        // For now, just launch "git" as a command.
+
+        let mut cmd = process::Command::new("git");
+        cmd.arg("diff");
+        cmd.arg(&commit.to_string()[..8]);
+        cmd.arg("--");
+        cmd.arg(dir);
+        exec_or_spawn(&mut cmd)
+    }
+}
+
 // help
 
 #[derive(Debug, PartialEq, StructOpt)]
@@ -453,6 +512,7 @@ struct LogCommand {
 
 impl Command for LogCommand {
     fn execute(self) -> Result<i32> {
+        // See also "diff" -- these follow similar patterns
         let sess = app::AppSession::initialize_default()?;
 
         let mut q = graph::GraphQueryBuilder::default();
@@ -632,6 +692,10 @@ enum ShowCommands {
     /// Print a "thiscommit:" tag for copy/pasting
     TcTag(ShowTcTagCommand),
 
+    #[structopt(name = "toposort")]
+    /// Print the projects in topologically-sorted order
+    Toposort(ShowToposortCommand),
+
     #[structopt(name = "version")]
     /// Print the current version number of a project
     Version(ShowVersionCommand),
@@ -642,6 +706,7 @@ impl Command for ShowCommand {
         match self.command {
             ShowCommands::IfReleased(o) => o.execute(),
             ShowCommands::TcTag(o) => o.execute(),
+            ShowCommands::Toposort(o) => o.execute(),
             ShowCommands::Version(o) => o.execute(),
         }
     }
@@ -727,6 +792,23 @@ impl Command for ShowTcTagCommand {
     }
 }
 
+#[derive(Debug, PartialEq, StructOpt)]
+struct ShowToposortCommand {}
+
+impl Command for ShowToposortCommand {
+    fn execute(self) -> Result<i32> {
+        let sess = app::AppSession::initialize_default()?;
+        let graph = sess.graph();
+
+        for ident in graph.toposorted() {
+            let proj = graph.lookup(ident);
+            println!("{}", proj.user_facing_name);
+        }
+
+        Ok(0)
+    }
+}
+
 // TODO: add something like `--ifdev=latest` to print "latest"
 // instead of 0.0.0-dev.0 if we're not on a release commit for
 // this project.
