@@ -16,7 +16,7 @@ use std::{
 use thiserror::Error as ThisError;
 
 use crate::{
-    atry,
+    a_ok_or, atry,
     bootstrap::BootstrapConfiguration,
     config::RepoConfiguration,
     errors::{Error, Result},
@@ -1433,6 +1433,27 @@ impl RepoHistory {
         self.release_commit
     }
 
+    /// Get the commit on the main branch associated with the
+    /// release commit of this chunk of history, if it exists.
+    pub fn main_branch_commit(&self, repo: &Repository) -> Result<Option<CommitId>> {
+        let rcid = match self.release_commit {
+            Some(c) => c,
+            None => return Ok(None),
+        };
+
+        let release_commit = repo.repo.find_commit(rcid.0)?;
+        let rc_commit = a_ok_or!(
+            release_commit.parents().last();
+            ["release commit has no parents?"]
+        );
+        let main_commit = a_ok_or!(
+            rc_commit.parents().last();
+            ["rc commit has no parents?"]
+        );
+
+        Ok(Some(CommitId(main_commit.id())))
+    }
+
     /// Get the release information corresponding to this item's release commit.
     /// This might be "bootstrap" information without any age=0 releases.
     pub fn release_info(&self, repo: &Repository) -> Result<ReleaseCommitInfo> {
@@ -1590,7 +1611,7 @@ impl RepoPath {
         // include the separating items, which we want.
         let basename = self.0.rsplit(|c| *c == b'/').next().unwrap();
         let ndir = self.0.len() - basename.len();
-        return (&self.0[..ndir].as_ref(), basename.as_ref());
+        return (self.0[..ndir].as_ref(), basename.as_ref());
     }
 
     /// Get the length of the path, in bytes
